==> xdphys-2.7.3.tar.gz: xdphys/src/xdphyslib.h <==
/*#include <audio.h> from is-indi.c */
#include <assert.h>
#include <ctype.h>
#include <errno.h>
#include <fcntl.h>
#include <math.h>
#include <pwd.h>
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <strings.h>
#include <termios.h>
#include <time.h>
#include <malloc.h>
#include <unistd.h>
#include <stdarg.h>
#include <values.h>

#include <Plotter.h>
#include <Plot.h>
#include <TextPlot.h>
#include <QuadAxis.h>
#include <QuadLinePlot.h>
#include <QuadBarPlot.h>
#include <psdriver.h>

#include <X11/Core.h>
#include <X11/CoreP.h>
#include <X11/cursorfont.h>
#include <X11/keysym.h>
#include <X11/Intrinsic.h>
#include <X11/IntrinsicP.h>
#include <X11/StringDefs.h>
#include <X11/Shell.h>
#include <X11/X.h>
#include <X11/Xaw/AsciiText.h>
#include <X11/Xaw/Box.h>
#include <X11/Xaw/Cardinals.h>
#include <X11/Xaw/Command.h>
#include <X11/Xaw/Dialog.h>
#include <X11/Xaw/Form.h>
#include <X11/Xaw/Label.h>
#include <X11/Xaw/List.h>
#include <X11/Xaw/MenuButton.h>
#include <X11/Xaw/Paned.h>
#include <X11/Xaw/Scrollbar.h>
#include <X11/Xaw/SimpleMenu.h>
#include <X11/Xaw/Sme.h>
#include <X11/Xaw/SmeLine.h>
#include <X11/Xaw/SmeBSB.h>
#include <X11/Xaw/Text.h>
#include <X11/Xaw/Toggle.h>
#include <X11/Xaw/Viewport.h>
#include <X11/Xatom.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>

#ifdef X11R4
# define asciiTextWidgetClass           asciiStringWidgetClass
# define asciiDiskWidgetClass           asciiStringWidgetClass
# define XawTextBlock                   XtTextBlock
# define XawtextEdit                    XttextEdit
# define XawtextRead                    XttextRead
# define XawTextPosition                XtTextPosition
# define XawTextSetInsertionPoint       XtTextSetInsertionPoint
# define XawTextReplace                 XtTextReplace
# define XawScrollbarSetThumb   XtScrollBarSetThumb
# define XawDialogAddButton             XtDialogAddButton
# define XawDialogGetValueString        XtDialogGetValueString
#endif /* X11R4 */

#include <sys/dir.h>
/*#include <sys/ioctl.h>*/
#include <sys/ipc.h>
#include <sys/fcntl.h>
#include <sys/file.h>
#include <sys/param.h>
#include <sys/shm.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>

#ifdef NR
# include <nr.h>
# include <nrutil.h>
#endif

#include <sanal/srl.h>
#include <sanal/sahist.h>
#include <sanal/psth.h>
#include <sanal/isih.h>
#include <sanal/correl.h>
#include <sanal/density.h>

#include <synth/synth.h>
#include <synth/calib.h>
#include <synth/cache.h>
#include <synth/stimarray.h>
#include <synth/misc.h>

#include "synthlib.h"
#include "version.h"
#include "xdphysio.h"
#include "iserver.h"
#include "runstop.h"
#include "waver.h"
#include "svars.h"
#include "systems.h"
#include "waveio.h"
#include "misc.h"
#include "xloop.h"
#include "ss_user.h"
#include "keeper.h"
#include "getfile.h"
#include "pop.h"
#include "button.h"
#include "xstuff.h"
#include "atgraph.h"
#include "Canvas.h"
#include "CanvasP.h"
#include "Wave.h"
#include "mathfns.h"
#include "fopen2.h"
#include "statline.h"
#include "parms.h"
#include "spike_t.h"
#include "nr_misc.h"
#include "fd.h"
#include "raster.h"
#include "menu.h"
#include "fdobj.h"
#include "fd1.h"
#include "dynraster.h"
#include "unittrace.h"
#include "ws.h"
#include "dloop.h"
#include "match.h"
#include "smenu.h"
#include "slider.h"
#include "signals.h"
#include "CircPerc.h"
#include "CircPercP.h"
#include "WaveP.h"
#include "Wave.h"
#include "addacal.h"
#include "analogfns.h"
#include "cutpaste.h"
#include "atmisc.h"
#include "att.h"
#include "bench.h"
#include "clockbar.h"
#include "clock.h"
#include "locks.h"
#include "comments.h"
#include "dock.h"
#include "dsp.h"
#include "iviewer.h"
#include "notepad.h"
#include "statfns.h"
#include "sleep.h"

#ifdef DMALLOC
#include <dmalloc.h>
#endif

==> xdphys-2.8.1.tar.gz: xdphys/src/xdphyslib.h <==
/*#include <audio.h> from is-indi.c */
#include <assert.h>
#include <ctype.h>
#include <errno.h>
#include <fcntl.h>
#include <math.h>
#include <pwd.h>
#include <signal.h>
#include <stdio.h>
#include <stdlib.h>
#include <strings.h>
#include <termios.h>
#include <time.h>
#include <malloc.h>
#include <unistd.h>
#include <stdarg.h>
#include <values.h>

#include <Plotter.h>
#include <Plot.h>
#include <TextPlot.h>
#include <QuadAxis.h>
#include <QuadLinePlot.h>
#include <QuadBarPlot.h>
#include <psdriver.h>

#include <X11/Core.h>
#include <X11/CoreP.h>
#include <X11/cursorfont.h>
#include <X11/keysym.h>
#include <X11/Intrinsic.h>
#include <X11/IntrinsicP.h>
#include <X11/StringDefs.h>
#include <X11/Shell.h>
#include <X11/X.h>
#include <X11/Xaw/AsciiText.h>
#include <X11/Xaw/Box.h>
#include <X11/Xaw/Cardinals.h>
#include <X11/Xaw/Command.h>
#include <X11/Xaw/Dialog.h>
#include <X11/Xaw/Form.h>
#include <X11/Xaw/Label.h>
#include <X11/Xaw/List.h>
#include <X11/Xaw/MenuButton.h>
#include <X11/Xaw/Paned.h>
#include <X11/Xaw/Scrollbar.h>
#include <X11/Xaw/SimpleMenu.h>
#include <X11/Xaw/Sme.h>
#include <X11/Xaw/SmeLine.h>
#include <X11/Xaw/SmeBSB.h>
#include <X11/Xaw/Text.h>
#include <X11/Xaw/Toggle.h>
#include <X11/Xaw/Viewport.h>
#include <X11/Xatom.h>
#include <X11/Xlib.h>
#include <X11/Xutil.h>

#ifdef X11R4
# define asciiTextWidgetClass           asciiStringWidgetClass
# define asciiDiskWidgetClass           asciiStringWidgetClass
# define XawTextBlock                   XtTextBlock
# define XawtextEdit                    XttextEdit
# define XawtextRead                    XttextRead
# define XawTextPosition                XtTextPosition
# define XawTextSetInsertionPoint       XtTextSetInsertionPoint
# define XawTextReplace                 XtTextReplace
# define XawScrollbarSetThumb   XtScrollBarSetThumb
# define XawDialogAddButton             XtDialogAddButton
# define XawDialogGetValueString        XtDialogGetValueString
#endif				/* X11R4 */

#include <sys/dir.h>
/*#include <sys/ioctl.h>*/
#include <sys/ipc.h>
#include <sys/fcntl.h>
#include <sys/file.h>
#include <sys/param.h>
#include <sys/shm.h>
#include <sys/stat.h>
#include <sys/time.h>
#include <sys/types.h>
#include <sys/wait.h>

#ifdef NR
# include <nr.h>
# include <nrutil.h>
#endif

#include <sanal/srl.h>
#include <sanal/sahist.h>
#include <sanal/psth.h>
#include <sanal/isih.h>
#include <sanal/correl.h>
#include <sanal/density.h>

#include <synth/synth.h>
#include <synth/calib.h>
#include <synth/cache.h>
#include <synth/stimarray.h>
#include <synth/misc.h>

#include "synthlib.h"
#include "version.h"
#include "xdphysio.h"
#include "iserver.h"
#include "runstop.h"
#include "waver.h"
#include "svars.h"
#include "systems.h"
#include "waveio.h"
#include "misc.h"
#include "xloop.h"
#include "ss_user.h"
#include "keeper.h"
#include "getfile.h"
#include "pop.h"
#include "button.h"
#include "xstuff.h"
#include "atgraph.h"
#include "Canvas.h"
#include "CanvasP.h"
#include "Wave.h"
#include "mathfns.h"
#include "fopen2.h"
#include "statline.h"
#include "parms.h"
#include "spike_t.h"
#include "fd.h"
#include "menu.h"
#include "fdobj.h"
#include "fd1.h"
#include "dynraster.h"
#include "unittrace.h"
#include "ws.h"
#include "dloop.h"
#include "match.h"
#include "smenu.h"
#include "slider.h"
#include "signals.h"
#include "CircPerc.h"
#include "CircPercP.h"
#include "WaveP.h"
#include "Wave.h"
#include "addacal.h"
#include "cutpaste.h"
#include "atmisc.h"
#include "att.h"
#include "bench.h"
#include "clockbar.h"
#include "clock.h"
#include "locks.h"
#include "comments.h"
#include "dock.h"
#include "dsp.h"
#include "iviewer.h"
#include "notepad.h"
#include "statfns.h"
#include "sleep.h"
#include "dataio.h"
#include "autolog.h"


#ifdef DMALLOC
#include <dmalloc.h>
#endif
